@@ -112,7 +112,7 @@ class AuthenticateCognitoAction(
 ):
     '''A Listener Action to authenticate with Cognito.
 
-    :exampleMetadata: lit=test/integ.cognito.lit.ts
+    :exampleMetadata: lit=test/integ.cognito.lit.ts infused
 
     Example::
 
@@ -261,7 +261,7 @@ class AuthenticateCognitoActionProps:
         :param session_cookie_name: The name of the cookie used to maintain session information. Default: "AWSELBAuthSessionCookie"
         :param session_timeout: The maximum duration of the authentication session. Default: Duration.days(7)
 
-        :exampleMetadata: lit=test/integ.cognito.lit.ts
+        :exampleMetadata: lit=test/integ.cognito.lit.ts infused
 
         Example::
 
